@@ -19,16 +19,22 @@ from __future__ import division
 from __future__ import unicode_literals
 
 import re
-
+from typing import Sequence, Set, Tuple
 
 from googlecloudsdk.api_lib.datastore import util
 from googlecloudsdk.api_lib.firestore import api_utils as firestore_utils
 from googlecloudsdk.api_lib.firestore import indexes as firestore_indexes
+from googlecloudsdk.appengine.datastore import datastore_index
+from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.core.console import progress_tracker
-from googlecloudsdk.third_party.appengine.datastore import datastore_index
+from googlecloudsdk.generated_clients.apis.datastore.v1 import datastore_v1_client
+from googlecloudsdk.generated_clients.apis.datastore.v1 import datastore_v1_messages
+from googlecloudsdk.generated_clients.apis.firestore.v1 import firestore_v1_messages
 
 
-def GetIndexesService():
+def GetIndexesService() -> (
+    datastore_v1_client.DatastoreV1.ProjectsIndexesService
+):
   """Returns the service for interacting with the Datastore Admin Service.
 
   This is used to manage the datastore indexes (create/delete).
@@ -77,7 +83,9 @@ FIRESTORE_DESCENDING = (
 )
 
 
-def ApiMessageToIndexDefinition(proto):
+def ApiMessageToIndexDefinition(
+    proto: datastore_v1_messages.GoogleDatastoreAdminV1Index,
+) -> Tuple[str, datastore_index.Index]:
   """Converts a GoogleDatastoreAdminV1Index to an index definition structure."""
   properties = []
   for prop_proto in proto.properties:
@@ -98,7 +106,9 @@ def _Fullmatch(regex, string):
   return re.match('(?:' + regex + r')\Z', string, flags=0)
 
 
-def CollectionIdAndIndexIdFromResourcePath(resource_path):
+def CollectionIdAndIndexIdFromResourcePath(
+    resource_path: str,
+) -> Tuple[str, str]:
   """Extracts collectionId and indexId from a collectionGroup resource path.
 
   Args:
@@ -120,7 +130,9 @@ def CollectionIdAndIndexIdFromResourcePath(resource_path):
   return match.group(3), match.group(4)
 
 
-def FirestoreApiMessageToIndexDefinition(proto):
+def FirestoreApiMessageToIndexDefinition(
+    proto: firestore_v1_messages.GoogleFirestoreAdminV1Index,
+) -> Tuple[str, datastore_index.Index]:
   """Converts a GoogleFirestoreAdminV1Index to an index definition structure.
 
   Args:
@@ -137,7 +149,12 @@ def FirestoreApiMessageToIndexDefinition(proto):
   properties = []
   for field_proto in proto.fields:
     prop_definition = datastore_index.Property(name=str(field_proto.fieldPath))
-    if field_proto.order == FIRESTORE_DESCENDING:
+    if field_proto.vectorConfig is not None:
+      prop_definition.vectorConfig = datastore_index.VectorConfig(
+          dimension=field_proto.vectorConfig.dimension,
+          flat=datastore_index.VectorFlatIndex(),
+      )
+    elif field_proto.order == FIRESTORE_DESCENDING:
       prop_definition.direction = 'desc'
     else:
       prop_definition.direction = 'asc'
@@ -158,7 +175,12 @@ def FirestoreApiMessageToIndexDefinition(proto):
   return index_id, index
 
 
-def BuildIndexProto(ancestor, kind, project_id, properties):
+def BuildIndexProto(
+    ancestor: datastore_v1_messages.GoogleDatastoreAdminV1Index.AncestorValueValuesEnum,
+    kind: str,
+    project_id: str,
+    properties: Sequence[datastore_index.Property],
+) -> datastore_v1_messages.GoogleDatastoreAdminV1Index:
   """Builds and returns a GoogleDatastoreAdminV1Index."""
   messages = util.GetMessages()
   proto = messages.GoogleDatastoreAdminV1Index()
@@ -170,6 +192,10 @@ def BuildIndexProto(ancestor, kind, project_id, properties):
   for prop in properties:
     prop_proto = messages.GoogleDatastoreAdminV1IndexedProperty()
     prop_proto.name = prop.name
+    if prop.vectorConfig is not None:
+      raise ValueError(
+          'Vector Indexes cannot be created via the Datastore Admin API'
+      )
     if prop.direction == 'asc':
       prop_proto.direction = ASCENDING
     else:
@@ -179,18 +205,33 @@ def BuildIndexProto(ancestor, kind, project_id, properties):
   return proto
 
 
-def BuildIndexFirestoreProto(is_ancestor, properties):
+def BuildIndexFirestoreProto(
+    name: str,
+    is_ancestor: bool,
+    properties: Sequence[datastore_index.Property],
+    enable_vector: bool = True,
+) -> firestore_v1_messages.GoogleFirestoreAdminV1Index:
   """Builds and returns a GoogleFirestoreAdminV1Index."""
   messages = firestore_utils.GetMessages()
   proto = messages.GoogleFirestoreAdminV1Index()
 
+  proto.name = name
   proto.queryScope = COLLECTION_RECURSIVE if is_ancestor else COLLECTION_GROUP
   proto.apiScope = DATASTORE_API_SCOPE
   fields = []
   for prop in properties:
     field_proto = messages.GoogleFirestoreAdminV1IndexField()
     field_proto.fieldPath = prop.name
-    if prop.direction == 'asc':
+    if prop.vectorConfig is not None:
+      if not enable_vector:
+        raise exceptions.InvalidArgumentException(
+            'index.yaml',
+            'Vector Indexes are currently only supported in the Alpha Track',
+        )
+      field_proto.vectorConfig = messages.GoogleFirestoreAdminV1VectorConfig()
+      field_proto.vectorConfig.dimension = prop.vectorConfig.dimension
+      field_proto.vectorConfig.flat = messages.GoogleFirestoreAdminV1FlatIndex()
+    elif prop.direction == 'asc':
       field_proto.order = FIRESTORE_ASCENDING
     else:
       field_proto.order = FIRESTORE_DESCENDING
@@ -199,8 +240,12 @@ def BuildIndexFirestoreProto(is_ancestor, properties):
   return proto
 
 
-def BuildIndex(is_ancestor, kind, properties):
-  """Builds and returns an index rep via GoogleDatastoreAdminV1Index."""
+def BuildIndex(
+    is_ancestor: bool,
+    kind: str,
+    properties: Sequence[Tuple[str, str]],
+) -> datastore_index.Index:
+  """Builds and returns a datastore_index.Index YAML rep object."""
   index = datastore_index.Index(
       kind=str(kind),
       properties=[
@@ -212,21 +257,65 @@ def BuildIndex(is_ancestor, kind, properties):
   return index
 
 
-def NormalizeIndexes(indexes):
+def NormalizeIndexesForDatastoreApi(
+    indexes: Sequence[datastore_index.Index],
+) -> Set[datastore_index.Index]:
   """Removes the last index property if it is __key__:asc which is redundant."""
-  if not indexes:
-    return set()
-  for index in indexes:
-    if (
-        index.properties
-        and index.properties[-1].name == '__key__'
-        and index.properties[-1].direction == 'asc'
-    ):
-      index.properties.pop()
+  indexes = indexes or []
+  for index in indexes or []:
+    NormalizeIndexForDatastoreApi(index)
   return set(indexes)
 
 
-def ListIndexes(project_id):
+def NormalizeIndexForDatastoreApi(
+    index: datastore_index.Index,
+) -> datastore_index.Index:
+  """Removes the last index property if it is __key__:asc which is redundant."""
+  if (
+      index.properties
+      # The key property path is represented as __key__ in Datastore API
+      # and __name__ in Firestore API.
+      and index.properties[-1].name in ('__key__', '__name__')
+      and index.properties[-1].direction == 'asc'
+  ):
+    index.properties.pop()
+  return index
+
+
+def NormalizeIndexesForFirestoreApi(
+    indexes: Sequence[datastore_index.Index],
+) -> Set[datastore_index.Index]:
+  """Removes the last index property if it is __name__:asc which is redundant."""
+  indexes = indexes or []
+  for index in indexes or []:
+    NormalizeIndexForFirestoreApi(index)
+  return set(indexes)
+
+
+def NormalizeIndexForFirestoreApi(
+    index: datastore_index.Index,
+) -> datastore_index.Index:
+  """Removes the last index property if it is __name__:asc which is redundant."""
+  # Firestore API returns index with '__name__' as opposed to Datastore which
+  # returns it as '__key__', normalize that here.
+  for prop in index.properties:
+    if prop.name == '__key__':
+      prop.name = '__name__'
+
+  # If the last property is '__name__ ASC', then we can remove it as the backend
+  # assumes that is the case.
+  if (
+      index.properties
+      # The key property path is represented as __key__ in Datastore API
+      # and __name__ in Firestore API.
+      and index.properties[-1].name in ('__key__', '__name__')
+      and index.properties[-1].direction == 'asc'
+  ):
+    index.properties.pop()
+  return index
+
+
+def ListIndexes(project_id: str) -> Sequence[datastore_index.Index]:
   """Lists all datastore indexes under a database with Datastore Admin API."""
   response = GetIndexesService().List(
       util.GetMessages().DatastoreProjectsIndexesListRequest(
@@ -236,7 +325,10 @@ def ListIndexes(project_id):
   return {ApiMessageToIndexDefinition(index) for index in response.indexes}
 
 
-def ListDatastoreIndexesViaFirestoreApi(project_id, database_id):
+def ListDatastoreIndexesViaFirestoreApi(
+    project_id: str,
+    database_id: str,
+) -> Sequence[datastore_index.Index]:
   """Lists all datastore indexes under a database with Firestore Admin API.
 
   Args:
@@ -254,8 +346,11 @@ def ListDatastoreIndexesViaFirestoreApi(project_id, database_id):
   }
 
 
-def CreateIndexes(project_id, indexes_to_create):
-  """Sends the index creation requests."""
+def CreateIndexesViaDatastoreApi(
+    project_id: str,
+    indexes_to_create: Sequence[datastore_index.Index],
+) -> None:
+  """Sends the index creation requests via the Datastore Admin API."""
   cnt = 0
   detail_message = None
   with progress_tracker.ProgressTracker(
@@ -275,8 +370,13 @@ def CreateIndexes(project_id, indexes_to_create):
       pt.Tick()
 
 
-def CreateIndexesViaFirestoreApi(project_id, database_id, indexes_to_create):
-  """Sends the index creation requests via Firestore API."""
+def CreateIndexesViaFirestoreApi(
+    project_id: str,
+    database_id: str,
+    indexes_to_create: Sequence[datastore_index.Index],
+    enable_vector: bool,
+) -> None:
+  """Sends the index creation requests via the Firestore Admin API."""
   detail_message = None
   with progress_tracker.ProgressTracker(
       '.', autotick=False, detail_message_callback=lambda: detail_message
@@ -286,14 +386,22 @@ def CreateIndexesViaFirestoreApi(project_id, database_id, indexes_to_create):
           project_id,
           database_id,
           index.kind,
-          BuildIndexFirestoreProto(index.ancestor, index.properties),
+          BuildIndexFirestoreProto(
+              name=None,
+              is_ancestor=index.ancestor,
+              properties=index.properties,
+              enable_vector=enable_vector,
+          ),
       )
       detail_message = '{0:.0%}'.format(i / len(indexes_to_create))
       pt.Tick()
 
 
-def DeleteIndexes(project_id, indexes_to_delete_ids):
-  """Sends the index deletion requests."""
+def DeleteIndexes(
+    project_id: str,
+    indexes_to_delete_ids: Sequence[str],
+) -> None:
+  """Sends the index deletion requests via the Datastore Admin API."""
   cnt = 0
   detail_message = None
   with progress_tracker.ProgressTracker(
@@ -312,23 +420,63 @@ def DeleteIndexes(project_id, indexes_to_delete_ids):
       pt.Tick()
 
 
-def CreateMissingIndexes(project_id, index_definitions):
+def DeleteIndexesViaFirestoreApi(
+    project_id: str,
+    database_id: str,
+    indexes_to_delete_ids: Sequence[str],
+) -> None:
+  """Sends the index deletion requests via the Firestore Admin API."""
+  cnt = 0
+  detail_message = None
+  delete_cnt = len(indexes_to_delete_ids)
+  with progress_tracker.ProgressTracker(
+      '.',
+      autotick=False,
+      detail_message_callback=lambda: detail_message,
+  ) as pt:
+    for index_id in indexes_to_delete_ids:
+      firestore_indexes.DeleteIndex(project_id, database_id, index_id)
+      cnt = cnt + 1
+      detail_message = '{0:.0%}'.format(cnt / delete_cnt)
+      pt.Tick()
+
+
+def CreateMissingIndexesViaDatastoreApi(
+    project_id: str,
+    index_definitions: datastore_index.IndexDefinitions,
+) -> None:
   """Creates the indexes if the index configuration is not present."""
   indexes = ListIndexes(project_id)
-  normalized_indexes = NormalizeIndexes(index_definitions.indexes)
+  normalized_indexes = NormalizeIndexesForDatastoreApi(
+      index_definitions.indexes
+  )
   new_indexes = normalized_indexes - {index for _, index in indexes}
-  CreateIndexes(project_id, new_indexes)
+  CreateIndexesViaDatastoreApi(project_id, new_indexes)
 
 
 def CreateMissingIndexesViaFirestoreApi(
-    project_id, database_id, index_definitions
-):
+    project_id: str,
+    database_id: str,
+    index_definitions: datastore_index.IndexDefinitions,
+    enable_vector: bool,
+) -> None:
   """Creates the indexes via Firestore API if the index configuration is not present."""
-  indexes = ListDatastoreIndexesViaFirestoreApi(project_id, database_id)
-  normalized_indexes = NormalizeIndexes(index_definitions.indexes)
-  new_indexes = normalized_indexes - {index for _, index in indexes}
+  existing_indexes = ListDatastoreIndexesViaFirestoreApi(
+      project_id, database_id
+  )
+  # Firestore API returns index with '__name__' field path. Normalizing the
+  # index is required.
+  existing_indexes_normalized = NormalizeIndexesForFirestoreApi(
+      [index for _, index in existing_indexes]
+  )
+  normalized_indexes = NormalizeIndexesForFirestoreApi(
+      index_definitions.indexes
+  )
+  new_indexes = normalized_indexes - existing_indexes_normalized
+
   CreateIndexesViaFirestoreApi(
       project_id=project_id,
       database_id=database_id,
       indexes_to_create=new_indexes,
+      enable_vector=enable_vector,
   )
