@@ -24,13 +24,14 @@ from googlecloudsdk.command_lib.components import util
 
 
 class Reinstall(base.SilentCommand):
-  """Reinstall the Cloud SDK with the same components you have now.
+  """Reinstall the Google Cloud CLI with the same components you have now.
 
-  If your Cloud SDK installation becomes corrupt, this command attempts to fix
-  it by downloading the latest version of the Cloud SDK and reinstalling it.
-  This will replace your existing installation with a fresh one.  The command is
-  the equivalent of deleting your current installation, downloading a fresh
-  copy of the SDK, and installing in the same location.
+  If your Google Cloud CLI installation becomes corrupt, this command attempts
+  to fix it by downloading the latest version of the Google Cloud CLI and
+  reinstalling it. This will replace your existing installation with a fresh
+  one.  The command is the equivalent of deleting your current installation,
+  downloading a fresh copy of the gcloud CLI, and installing in the same
+  location.
 
   ## EXAMPLES
   To reinstall all components you have installed, run:
