@@ -1,4 +1,5 @@
-# Copyright 2014 Google Inc. All Rights Reserved.
+# -*- coding: utf-8 -*- #
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,10 +15,14 @@
 
 """gcloud dns record-sets transaction abort command."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import unicode_literals
+
 import os
 
+from googlecloudsdk.api_lib.dns import transaction_util
 from googlecloudsdk.calliope import base
-from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.dns import flags
 from googlecloudsdk.core import log
 
@@ -31,7 +36,7 @@ class Abort(base.Command):
 
   To abort the transaction, run:
 
-    $ {command} --zone MANAGED_ZONE
+    $ {command} --zone=MANAGED_ZONE
   """
 
   @staticmethod
@@ -40,8 +45,8 @@ class Abort(base.Command):
 
   def Run(self, args):
     if not os.path.isfile(args.transaction_file):
-      raise exceptions.ToolException(
-          'transaction not found at [{0}]'.format(args.transaction_file))
+      raise transaction_util.TransactionFileNotFound(
+          'Transaction not found at [{0}]'.format(args.transaction_file))
 
     os.remove(args.transaction_file)
 
