@@ -25,7 +25,8 @@ from googlecloudsdk.command_lib.network_connectivity import flags
 from googlecloudsdk.command_lib.network_connectivity import util
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.UniverseCompatible
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class List(base.ListCommand):
   """List spokes.
 
