@@ -23,7 +23,6 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.secrets import args as secrets_args
 from googlecloudsdk.command_lib.secrets import fmt as secrets_fmt
-from googlecloudsdk.command_lib.secrets import util as secrets_util
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
@@ -41,20 +40,21 @@ class ListBeta(base.ListCommand):
 
   @staticmethod
   def Args(parser):
+    api_version = secrets_api.GetApiFromTrack(base.ReleaseTrack.BETA)
     secrets_args.AddProject(parser)
-    secrets_fmt.UseLocationTable(parser, 'v1beta1')
+    secrets_fmt.UseLocationTable(parser, api_version=api_version)
 
   def Run(self, args):
+    api_version = secrets_api.GetApiFromTrack(self.ReleaseTrack())
     project_ref = args.CONCEPTS.project.Parse()
     if not project_ref:
       raise exceptions.RequiredArgumentException(
           'project',
           'Please set a project with "--project" flag or "gcloud config set project <project_id>".'
       )
-    return secrets_api.Locations(
-        version=secrets_util.GetVersionFromReleasePath(
-            self.ReleaseTrack())).ListWithPager(
-                project_ref=project_ref, limit=args.limit)
+    return secrets_api.Locations(api_version=api_version).ListWithPager(
+        project_ref=project_ref, limit=args.limit
+    )
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
@@ -72,17 +72,18 @@ class List(base.ListCommand):
 
   @staticmethod
   def Args(parser):
+    api_version = secrets_api.GetApiFromTrack(base.ReleaseTrack.GA)
     secrets_args.AddProject(parser)
-    secrets_fmt.UseLocationTable(parser, 'v1')
+    secrets_fmt.UseLocationTable(parser, api_version)
 
   def Run(self, args):
+    api_version = secrets_api.GetApiFromTrack(self.ReleaseTrack())
     project_ref = args.CONCEPTS.project.Parse()
     if not project_ref:
       raise exceptions.RequiredArgumentException(
           'project',
           'Please set a project with "--project" flag or "gcloud config set project <project_id>".'
       )
-    return secrets_api.Locations(
-        version=secrets_util.GetVersionFromReleasePath(
-            self.ReleaseTrack())).ListWithPager(
-                project_ref=project_ref, limit=args.limit)
+    return secrets_api.Locations(api_version=api_version).ListWithPager(
+        project_ref=project_ref, limit=args.limit
+    )
