@@ -188,8 +188,7 @@ class Copy(base.Command):
         help='The number of threads to use for the copy.')
 
   def Run(self, args):
-    # TODO(b/190541521):  Determine if command group works with project number
-    base.RequireProjectID(args)
+
     sources = [paths.Path(p) for p in args.source]
     dest = paths.Path(args.destination)
     copier = copying.CopyTaskGenerator()
